﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

namespace IPGUI
{
    public class GradientButton : Control
    {
        private StringFormat strFormat = new StringFormat();
        public GradientButton()
        {
            strFormat.Alignment = StringAlignment.Center;
            strFormat.LineAlignment = StringAlignment.Center;
            Paint += _Paint;
            Font = new Font("sans-serif", 9);
        }

        private void _Paint(object sender, PaintEventArgs e)
        {
            e.Graphics.SmoothingMode = SmoothingMode.HighQuality;
            Rectangle r = new Rectangle(0, 0, Width, Height);
            LinearGradientBrush gradient = new LinearGradientBrush(r, Color.FromArgb(0xdb, 0x00, 0xb2), Color.FromArgb(0xeb, 0x00, 0x4e), 0.0f);
            using (GraphicsPath path = RoundedRect(r, 15))
            {
                e.Graphics.FillPath(gradient, path);
            }
            e.Graphics.DrawString(Text, Font, new SolidBrush(Color.White), r, strFormat);
        }

        public static GraphicsPath RoundedRect(Rectangle bounds, int radius)
        {
            int diameter = radius * 2;
            Size size = new Size(diameter, diameter);
            Rectangle arc = new Rectangle(bounds.Location, size);
            GraphicsPath path = new GraphicsPath();
            if (radius == 0)
            {
                path.AddRectangle(bounds);
                return path;
            } 
            path.AddArc(arc, 180, 90);
            arc.X = bounds.Right - diameter;
            path.AddArc(arc, 270, 90);
            arc.Y = bounds.Bottom - diameter;
            path.AddArc(arc, 0, 90);
            arc.X = bounds.Left;
            path.AddArc(arc, 90, 90);
            path.CloseFigure();
            return path;
        }
    }
}
